==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/meta/base/v1/BaseMetaDO.java <==
package com.valor.vod.api.model.meta.base.v1;

import com.valor.vod.api.model.constant.EPlaylistType;
import com.valor.vod.api.model.constant.EVideoType;
import com.valor.vod.api.model.meta.media.v1.CertificateDo;
import com.valor.vod.api.model.meta.media.v1.GenreDO;
import com.valor.vod.api.model.meta.media.v1.TrailerDO;
import com.valor.vod.api.model.tag.TagDo;

import java.util.*;

/**
 * @author Frank
 * @date 2016/1/8 10:48
 */
public class BaseMetaDO extends ChargeDO {
    /** metaid,此处为内部id,后面使用displayId,做为app和服务端传输的参数。 */
    protected long metaId;
    /** meta type */
    protected EVideoType metaType;
    /** vms展示id */
    protected String vid = "";
    /** 标题 */
    protected String title = "";
    /** 海报 */
    protected String poster = "";
    /** 背景 */
    protected String backdrop = "";
    /** 评分 */
    protected double rating = 0.0;
    /** 是否链接 */
    protected int linked = 0;
    /** 发行日期 */
    protected String releaseDate;
    /** tv_series 最后更新日期 */
    protected String lastAirDate;
    /** metaId2,用于和linked关联,以'tt','mm','aa' 开头 */
    protected String metaId2;
    /** logo,列表logo */
    protected String logo = "";
    /** logo2,列表logo2 */
    protected String logo2 = "";

    private String backgroundImage = "";
    protected List<AwardDo> awards = new ArrayList<>();
    protected List<TagDo> tags = new ArrayList<>();
    protected Map<String, String> extra = new HashMap<>();
    protected long runtime;
    protected String lastConnectedTime;
    protected String plot;
    protected List<GenreDO> genres = new ArrayList<>();
    private Long publishLastModifyTime;

    /** hot播放统计，所有时长 */
    private Long viewedAll = 0L;
    /** 播放次数格式化 */
    private String viewedFormat = "0";

    private String highlightTitle = "";

    /** 2.3版本新增布局格式属性 */
    private String layout;

    /** 2.3版本新增音频语言 */
    private List<String> audioLanguageList;

    /** 2.3版本新增字幕语言 */
    private List<String> subtitleList;
    /** 新增字幕语言 全称 */
    private List<String> subtitleFullList;
    /** 2.3版本新增 */
    private Map<String, CertificateDo> certificates = new HashMap<>();

    /** 3.0版本新增，从PlaylistMetaDO中迁移过来 */
    private EPlaylistType listType;

    private List<TrailerDO> trailerList = new ArrayList<>();

    /** 3.0版本新增展示类型，值为extra属性中displayType */
    private String displayType;

    /** 只作为缓存使用，用来计算用户相关信息，不返回给终端 */
    private Set<Long> clouds = new LinkedHashSet();

    private Set<String> cloudsAudioLanguage = new LinkedHashSet();

    private String checksum;

    /** 流行指数 */
    private Double popularity = 0.0;

    /** 0 no, 1 yes */
    private Integer isKnown = 0;

    private List<String> countryCodes;

    public String getPlot() {
        return plot;
    }

    public void setPlot(String plot) {
        this.plot = plot;
    }

    public long getMetaId() {
        return metaId;
    }

    public void setMetaId(long metaId) {
        this.metaId = metaId;
    }

    public EVideoType getMetaType() {
        return metaType;
    }

    public void setMetaType(EVideoType metaType) {
        this.metaType = metaType;
    }

    public void setMetaTypeInt(int metaType) {
        this.metaType = EVideoType.valueOf(metaType);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public double getRating() {
        return rating;
    }

    public void setRating(double rating) {
        this.rating = rating;
    }

    public int getLinked() {
        return linked;
    }

    public void setLinked(int linked) {
        this.linked = linked;
    }

    public String getPoster() {
        return poster;
    }

    public void setPoster(String poster) {
        this.poster = poster;
    }

    public String getBackdrop() {
        return backdrop;
    }

    public void setBackdrop(String backdrop) {
        this.backdrop = backdrop;
    }

    public String getVid() {
        return vid;
    }

    public void setVid(String vid) {
        this.vid = vid;
    }

    public List<AwardDo> getAwards() {
        return awards;
    }

    public void setAwards(List<AwardDo> awards) {
        this.awards = awards;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public String getLastAirDate() {
        return lastAirDate;
    }

    public void setLastAirDate(String lastAirDate) {
        this.lastAirDate = lastAirDate;
    }

    public String getMetaId2() {
        return metaId2;
    }

    public void setMetaId2(String metaId2) {
        this.metaId2 = metaId2;
    }

    public List<TagDo> getTags() {
        return tags;
    }

    public void setTags(List<TagDo> tags) {
        this.tags = tags;
    }

    public void addTags(List<TagDo> tagList) {
        if (tagList != null && tagList.size() > 0) {
            for (TagDo e : tagList) {
                if (!this.tags.contains(e)) {
                    this.tags.add(e);
                }
            }
        }
    }

    public Map<String, String> getExtra() {
        return extra;
    }

    public void setExtra(Map<String, String> extra) {
        this.extra = extra;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getLogo2() {
        return logo2;
    }

    public Long getPublishLastModifyTime() {
        return publishLastModifyTime;
    }

    public void setPublishLastModifyTime(Long publishLastModifyTime) {
        this.publishLastModifyTime = publishLastModifyTime;
    }

    public Long getViewedAll() {
        return viewedAll;
    }

    public void setViewedAll(Long viewedAll) {
        this.viewedAll = viewedAll;
    }

    public String getViewedFormat() {
        return viewedFormat;
    }

    public void setViewedFormat(String viewedFormat) {
        this.viewedFormat = viewedFormat;
    }

    public String getHighlightTitle() {
        return highlightTitle;
    }

    public void setHighlightTitle(String highlightTitle) {
        this.highlightTitle = highlightTitle;
    }

    public void setLogo2(String logo2) {
        this.logo2 = logo2;
    }

    public String getBackgroundImage() {
        return backgroundImage;
    }

    public void setBackgroundImage(String backgroundImage) {
        this.backgroundImage = backgroundImage;
    }

    public long getRuntime() {
        return runtime;
    }

    public void setRuntime(long runtime) {
        this.runtime = runtime;
    }

    public String getLastConnectedTime() {
        return lastConnectedTime;
    }

    public void setLastConnectedTime(String lastConnectedTime) {
        this.lastConnectedTime = lastConnectedTime;
    }

    public List<GenreDO> getGenres() {
        return genres;
    }

    public void setGenres(List<GenreDO> genres) {
        this.genres = genres;
    }

    public String getLayout() {
        return layout;
    }

    public void setLayout(String layout) {
        this.layout = layout;
    }

    public List<String> getAudioLanguageList() {
        return audioLanguageList;
    }

    public void setAudioLanguageList(List<String> audioLanguageList) {
        this.audioLanguageList = audioLanguageList;
    }

    public List<String> getSubtitleList() {
        return subtitleList;
    }

    public void setSubtitleList(List<String> subtitleList) {
        this.subtitleList = subtitleList;
    }

    public List<String> getSubtitleFullList() {
        return subtitleFullList;
    }

    public void setSubtitleFullList(List<String> subtitleFullList) {
        this.subtitleFullList = subtitleFullList;
    }

    public Map<String, CertificateDo> getCertificates() {
        return certificates;
    }

    public void setCertificates(Map<String, CertificateDo> certificates) {
        this.certificates = certificates;
    }

    public EPlaylistType getListType() {
        return listType;
    }

    public void setListType(EPlaylistType listType) {
        this.listType = listType;
    }

    public List<TrailerDO> getTrailerList() {
        return trailerList;
    }

    public void setTrailerList(List<TrailerDO> trailerList) {
        this.trailerList = trailerList;
    }

    public String getDisplayType() {
        return displayType;
    }

    public void setDisplayType(String displayType) {
        this.displayType = displayType;
    }

    public Set<Long> getClouds() {
        return clouds;
    }

    public void setClouds(Set<Long> clouds) {
        this.clouds = clouds;
    }

    public Set<String> getCloudsAudioLanguage() {
        return cloudsAudioLanguage;
    }

    public void setCloudsAudioLanguage(Set<String> cloudsAudioLanguage) {
        this.cloudsAudioLanguage = cloudsAudioLanguage;
    }

    public String getChecksum() {
        return checksum;
    }

    public void setChecksum(String checksum) {
        this.checksum = checksum;
    }

    public Double getPopularity() {
        return popularity;
    }

    public void setPopularity(Double popularity) {
        this.popularity = popularity;
    }

    public Integer getIsKnown() {
        return isKnown;
    }

    public void setIsKnown(Integer isKnown) {
        this.isKnown = isKnown;
    }

    public List<String> getCountryCodes() {
        return countryCodes;
    }

    public void setCountryCodes(List<String> countryCodes) {
        this.countryCodes = countryCodes;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        BaseMetaDO that = (BaseMetaDO) o;
        return metaId == that.metaId;
    }

    @Override
    public int hashCode() {
        return Objects.hash(metaId);
    }
}

==> vod-api-model-3.0.0-sources.jar: com/valor/vod/api/model/meta/base/v1/BaseMetaDO.java <==
package com.valor.vod.api.model.meta.base.v1;

import com.valor.vod.api.model.constant.EVideoType;
import com.valor.vod.api.model.meta.media.v1.GenreDO;
import com.valor.vod.api.model.tag.TagDo;

import java.util.*;

/**
 * Project     : volor
 * Description :
 * Author      : Frank
 * Create Time : 2016/1/8 10:48
 */
public class BaseMetaDO extends ChargeDO {
    protected long metaId;   //metaid,此处为内部id,后面使用displayId,做为app和服务端传输的参数。
    protected EVideoType metaType; //meta type
    protected String vid = "";   //vms展示id

    protected String title = ""; //标题
    protected String poster = "";  //海报
    protected String backdrop = "";  //背景
    protected double rating = 0.0; //评分
    protected int linked = 0;   //是否链接
    protected String releaseDate;    //发行日期
    protected String lastAirDate;    //tv_series 最后更新日期

    protected String metaId2;        //metaId2,用于和linked关联,以'tt','mm','aa' 开头
    protected String logo = "";  //logo,列表logo
    protected String logo2 = "";  //logo2,列表logo2
    private String backgroundImage = "";
    protected List<AwardDo> awards = new ArrayList<>();
    protected List<TagDo> tags = new ArrayList<>();
    protected Map<String, String> extra = new HashMap<>();
    protected long runtime;
    protected String lastConnectedTime;
    protected String plot;
    protected List<GenreDO> genres = new ArrayList<>();

    public String getPlot() {
        return plot;
    }

    public void setPlot(String plot) {
        this.plot = plot;
    }

    public long getMetaId() {
        return metaId;
    }

    public void setMetaId(long metaId) {
        this.metaId = metaId;
    }

    public EVideoType getMetaType() {
        return metaType;
    }

    public void setMetaType(EVideoType metaType) {
        this.metaType = metaType;
    }

    public void setMetaTypeInt(int metaType) {
        this.metaType = EVideoType.valueOf(metaType);
    }


    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public double getRating() {
        return rating;
    }

    public void setRating(double rating) {
        this.rating = rating;
    }

    public int getLinked() {
        return linked;
    }

    public void setLinked(int linked) {
        this.linked = linked;
    }

    public String getPoster() {
        return poster;
    }

    public void setPoster(String poster) {
        this.poster = poster;
    }

    public String getBackdrop() {
        return backdrop;
    }

    public void setBackdrop(String backdrop) {
        this.backdrop = backdrop;
    }

    public String getVid() {
        return vid;
    }

    public void setVid(String vid) {
        this.vid = vid;
    }

    public List<AwardDo> getAwards() {
        return awards;
    }

    public void setAwards(List<AwardDo> awards) {
        this.awards = awards;
    }

    public String getReleaseDate() {
        return releaseDate;
    }

    public void setReleaseDate(String releaseDate) {
        this.releaseDate = releaseDate;
    }

    public String getLastAirDate() {
        return lastAirDate;
    }

    public void setLastAirDate(String lastAirDate) {
        this.lastAirDate = lastAirDate;
    }

    public String getMetaId2() {
        return metaId2;
    }

    public void setMetaId2(String metaId2) {
        this.metaId2 = metaId2;
    }

    public List<TagDo> getTags() {
        return tags;
    }

    public void setTags(List<TagDo> tags) {
        this.tags = tags;
    }
    public void addTags(List<TagDo> tagList){
        if (tagList!= null && tagList.size()> 0){
            for (TagDo e:tagList){
                if (!this.tags.contains(e)){
                    this.tags.add(e);
                }
            }
        }
    }


    public Map<String, String> getExtra() {
        return extra;
    }

    public void setExtra(Map<String, String> extra) {
        this.extra = extra;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        BaseMetaDO that = (BaseMetaDO) o;
        return metaId == that.metaId;
    }

    @Override
    public int hashCode() {
        return Objects.hash(metaId);
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getLogo2() {
        return logo2;
    }

    public void setLogo2(String logo2) {
        this.logo2 = logo2;
    }

    public String getBackgroundImage() {
        return backgroundImage;
    }

    public void setBackgroundImage(String backgroundImage) {
        this.backgroundImage = backgroundImage;
    }

    public long getRuntime() {
        return runtime;
    }

    public void setRuntime(long runtime) {
        this.runtime = runtime;
    }

    public String getLastConnectedTime() {
        return lastConnectedTime;
    }

    public void setLastConnectedTime(String lastConnectedTime) {
        this.lastConnectedTime = lastConnectedTime;
    }
    public List<GenreDO> getGenres() {
        return genres;
    }

    public void setGenres(List<GenreDO> genres) {
        this.genres = genres;
    }
}
